@@ -22,21 +22,14 @@
 
 #include <libaudcore/audstrings.h>
 #include <libaudcore/i18n.h>
-#include <libaudcore/interface.h>
 #include <libaudcore/plugin.h>
 #include <libaudcore/runtime.h>
 
-#define ERROR AUDERR
-
-#define ERROR_NOISY(...) do { \
-    aud_ui_show_error (str_printf ("ALSA error: " __VA_ARGS__)); \
-} while (0)
-
 #define CHECK_VAL(value, function, ...) \
 do { \
     (value) = function (__VA_ARGS__); \
     if ((value) < 0) { \
-        ERROR ("%s failed: %s.\n", #function, snd_strerror (value)); \
+        AUDERR ("%s failed: %s.\n", #function, snd_strerror (value)); \
         goto FAILED; \
     } \
 } while (0)
@@ -47,11 +40,12 @@ do { \
     CHECK_VAL (CHECK_error, function, __VA_ARGS__); \
 } while (0)
 
-#define CHECK_NOISY(function, ...) \
+#define CHECK_STR(str, function, ...) \
 do { \
-    int CHECK_NOISY_error = function (__VA_ARGS__); \
-    if (CHECK_NOISY_error < 0) { \
-        ERROR_NOISY ("%s failed: %s.\n", #function, snd_strerror (CHECK_NOISY_error)); \
+    int CHECK_STR_error = function (__VA_ARGS__); \
+    if (CHECK_STR_error < 0) { \
+        str = String (str_printf ("ALSA error: %s failed: %s.\n", #function, \
+         snd_strerror (CHECK_STR_error))); \
         goto FAILED; \
     } \
 } while (0)
@@ -81,7 +75,7 @@ public:
     StereoVolume get_volume ();
     void set_volume (StereoVolume v);
 
-    bool open_audio (int aud_format, int rate, int chans);
+    bool open_audio (int aud_format, int rate, int chans, String & error);
     void close_audio ();
 
     void period_wait ();
