@@ -197,33 +197,6 @@ static void button_add_pressed ()
     audgui_run_filebrowser (false);
 }
 
-void set_ab_repeat_a ()
-{
-    if (! aud_drct_get_playing ())
-        return;
-
-    int a, b;
-    aud_drct_get_ab_repeat (a, b);
-    a = aud_drct_get_time ();
-    aud_drct_set_ab_repeat (a, b);
-}
-
-void set_ab_repeat_b ()
-{
-    if (! aud_drct_get_playing ())
-        return;
-
-    int a, b;
-    aud_drct_get_ab_repeat (a, b);
-    b = aud_drct_get_time ();
-    aud_drct_set_ab_repeat (a, b);
-}
-
-void clear_ab_repeat ()
-{
-    aud_drct_set_ab_repeat (-1, -1);
-}
-
 static void title_change (void * = nullptr)
 {
     delayed_title_change.stop ();
