@@ -193,7 +193,7 @@ private:
 NeonFile::NeonFile (const char * url) :
     m_url (url)
 {
-    int buffer_kb = aud_get_int (nullptr, "net_buffer_kb");
+    int buffer_kb = aud_get_int ("net_buffer_kb");
     m_rb.alloc (1024 * aud::clamp (buffer_kb, 16, 1024));
 }
 
@@ -434,10 +434,10 @@ void NeonFile::handle_headers ()
 static int neon_proxy_auth_cb (void * userdata, const char * realm, int attempt,
  char * username, char * password)
 {
-    String value = aud_get_str (nullptr, "proxy_user");
+    String value = aud_get_str ("proxy_user");
     g_strlcpy (username, value, NE_ABUFSIZ);
 
-    value = aud_get_str (nullptr, "proxy_pass");
+    value = aud_get_str ("proxy_pass");
     g_strlcpy (password, value, NE_ABUFSIZ);
 
     return attempt;
@@ -554,14 +554,30 @@ int NeonFile::open_handle (int64_t startbyte, String * error)
     int ret;
     String proxy_host;
     int proxy_port = 0;
+    String proxy_user (""); // ne_session_socks_proxy requires non NULL user and password
+    String proxy_pass ("");
+    bool socks_proxy = false;
+    ne_sock_sversion socks_type = NE_SOCK_SOCKSV4A;
 
-    bool use_proxy = aud_get_bool (nullptr, "use_proxy");
-    bool use_proxy_auth = aud_get_bool (nullptr, "use_proxy_auth");
+    bool use_proxy = aud_get_bool ("use_proxy");
+    bool use_proxy_auth = aud_get_bool ("use_proxy_auth");
 
     if (use_proxy)
     {
-        proxy_host = aud_get_str (nullptr, "proxy_host");
-        proxy_port = aud_get_int (nullptr, "proxy_port");
+        proxy_host = aud_get_str ("proxy_host");
+        proxy_port = aud_get_int ("proxy_port");
+        socks_proxy = aud_get_bool ("socks_proxy");
+
+        if (use_proxy_auth)
+        {
+            proxy_user = aud_get_str ("proxy_user");
+            proxy_pass = aud_get_str ("proxy_pass");
+        }
+
+        if (socks_proxy)
+        {
+            socks_type = aud_get_int ("socks_type") == 0 ? NE_SOCK_SOCKSV4A : NE_SOCK_SOCKSV5;
+        }
     }
 
     m_redircount = 0;
@@ -597,7 +613,14 @@ int NeonFile::open_handle (int64_t startbyte, String * error)
         if (use_proxy)
         {
             AUDDBG ("<%p> Using proxy: %s:%d\n", this, (const char *) proxy_host, proxy_port);
-            ne_session_proxy (m_session, proxy_host, proxy_port);
+            if (socks_proxy)
+            {
+                ne_session_socks_proxy (m_session, socks_type, proxy_host, proxy_port, proxy_user, proxy_pass);
+            }
+            else
+            {
+                ne_session_proxy (m_session, proxy_host, proxy_port);
+            }
 
             if (use_proxy_auth)
             {
