@@ -31,41 +31,45 @@ struct PixelSizes;
 class InfoBar : public QWidget
 {
 public:
-    InfoBar (QWidget * parent = nullptr);
+    InfoBar(QWidget * parent = nullptr);
 
-    void resizeEvent (QResizeEvent *);
-    void paintEvent (QPaintEvent *);
+    void resizeEvent(QResizeEvent *);
+    void paintEvent(QPaintEvent *);
 
 private:
-    void update_title ();
-    void update_album_art ();
-    void next_song ();
-    void do_fade ();
+    void update_title();
+    void update_album_art();
+    void next_song();
+    void do_fade();
 
-    void playback_ready_cb ();
-    void playback_stop_cb ();
-    void update_vis ();
+    void playback_ready_cb();
+    void playback_stop_cb();
+    void update_vis();
 
-    const HookReceiver<InfoBar>
-     hook1 {"tuple change", this, & InfoBar::update_title},
-     hook2 {"playback ready", this, & InfoBar::playback_ready_cb},
-     hook3 {"playback stop", this, & InfoBar::playback_stop_cb},
-     hook4 {"qtui toggle infoarea_vis", this, & InfoBar::update_vis};
+    const HookReceiver<InfoBar> hook1{"tuple change", this,
+                                      &InfoBar::update_title},
+        hook2{"playback ready", this, &InfoBar::playback_ready_cb},
+        hook3{"playback stop", this, &InfoBar::playback_stop_cb},
+        hook4{"qtui toggle infoarea_vis", this, &InfoBar::update_vis};
 
-    const Timer<InfoBar>
-     fade_timer {TimerRate::Hz30, this, & InfoBar::do_fade};
+    const Timer<InfoBar> fade_timer{TimerRate::Hz30, this, &InfoBar::do_fade};
 
     InfoVis * m_vis;
     const PixelSizes & ps;
 
-    struct SongData {
+    struct SongData
+    {
         QPixmap art;
         QString orig_title;
         QStaticText title, artist, album;
         int alpha;
     };
 
-    enum {Prev = 0, Cur = 1}; /* index into SongData array */
+    enum
+    {
+        Prev = 0,
+        Cur = 1
+    }; /* index into SongData array */
 
     SongData sd[2];
     bool m_stopped;
