@@ -20,6 +20,17 @@
 #ifndef SETTINGS_H
 #define SETTINGS_H
 
+#include <libaudcore/templates.h>
+
+#define DEFAULT_COLUMNS "playing title artist album queued length"
+
+enum PlaylistTabVisibility
+{
+    Always,
+    AutoHide,
+    Never
+};
+
 struct PluginPreferences;
 extern const PluginPreferences qtui_prefs;
 
