@@ -24,6 +24,7 @@
 #include <libaudcore/runtime.h>
 #include <libaudqt/libaudqt.h>
 
+#include <QApplication>
 #include <QMouseEvent>
 #include <QProxyStyle>
 #include <QStyle>
@@ -46,6 +47,13 @@ void TimeSliderLabel::mouseDoubleClickEvent(QMouseEvent * event)
 class TimeSliderStyle : public QProxyStyle
 {
 public:
+    TimeSliderStyle()
+    {
+        // detect and respond to application-wide style change
+        connect(qApp->style(), &QObject::destroyed, this,
+                &TimeSliderStyle::resetBaseStyle);
+    }
+
     int styleHint(QStyle::StyleHint hint, const QStyleOption * option = nullptr,
                   const QWidget * widget = nullptr,
                   QStyleHintReturn * returnData = nullptr) const
@@ -58,15 +66,25 @@ public:
 
         return styleHint;
     }
+
+private:
+    void resetBaseStyle()
+    {
+        setBaseStyle(nullptr);
+        connect(qApp->style(), &QObject::destroyed, this,
+                &TimeSliderStyle::resetBaseStyle);
+    }
 };
 
 TimeSlider::TimeSlider(QWidget * parent)
-    : QSlider(Qt::Horizontal, parent), m_label(new TimeSliderLabel(parent)),
-      m_style(new TimeSliderStyle)
+    : QSlider(Qt::Horizontal, parent), m_label(new TimeSliderLabel(parent))
 {
     setFocusPolicy(Qt::NoFocus);
     setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
-    setStyle(m_style);
+
+    auto style = new TimeSliderStyle;
+    style->setParent(this);
+    setStyle(style);
 
     m_label->setContentsMargins(audqt::sizes.FourPt, 0, 0, 0);
     m_label->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::MinimumExpanding);
@@ -78,8 +96,6 @@ TimeSlider::TimeSlider(QWidget * parent)
     start_stop();
 }
 
-TimeSlider::~TimeSlider() { delete m_style; }
-
 void TimeSlider::set_label(int time, int length)
 {
     QString text;
