@@ -39,7 +39,7 @@
 #include "equalizer.h"
 #include "main.h"
 #include "vis-callbacks.h"
-#include "playlist.h"
+#include "playlistwin.h"
 #include "skin.h"
 #include "window.h"
 #include "view.h"
