@@ -172,7 +172,7 @@ void PlaylistWidget::draw (cairo_t * cr)
 
     /* entry numbers */
 
-    if (aud_get_bool (nullptr, "show_numbers_in_pl"))
+    if (aud_get_bool ("show_numbers_in_pl"))
     {
         width = 0;
 
@@ -770,7 +770,7 @@ bool PlaylistWidget::motion (GdkEventMotion * event)
     {
         if (position == -1 || position == m_length)
             cancel_all ();
-        else if (aud_get_bool (nullptr, "show_filepopup_for_tuple") && m_popup_pos != position)
+        else if (aud_get_bool ("show_filepopup_for_tuple") && m_popup_pos != position)
         {
             cancel_all ();
             popup_trigger (position);
@@ -793,7 +793,7 @@ void PlaylistWidget::popup_trigger (int pos)
     audgui_infopopup_hide ();
 
     m_popup_pos = pos;
-    m_popup_timer.queue (aud_get_int (nullptr, "filepopup_delay") * 100,
+    m_popup_timer.queue (aud_get_int ("filepopup_delay") * 100,
      aud::obj_member<PlaylistWidget, & PlaylistWidget::popup_show>, this);
 }
 
