@@ -43,6 +43,10 @@ void view_show_player (bool show)
 {
     if (show)
     {
+        // "Move" the window to the position it's already at. This seems
+        // to work around a GTK+ bug causing the main window to end up
+        // at a random position after the gtk_window_present() call.
+        mainwin->move (config.player_x, config.player_y);
         gtk_window_present ((GtkWindow *) mainwin->gtk ());
         show_plugin_windows ();
     }
@@ -75,6 +79,8 @@ void view_apply_show_playlist ()
 
     if (show && gtk_widget_get_visible (main))
     {
+        // Same workaround as for the main window
+        playlistwin->move (config.playlist_x, config.playlist_y);
         gtk_window_set_transient_for ((GtkWindow *) pl, (GtkWindow *) main);
         gtk_window_present ((GtkWindow *) pl);
     }
@@ -101,6 +107,8 @@ void view_apply_show_equalizer ()
 
     if (show && gtk_widget_get_visible (main))
     {
+        // Same workaround as for the main window
+        equalizerwin->move (config.equalizer_x, config.equalizer_y);
         gtk_window_set_transient_for ((GtkWindow *) eq, (GtkWindow *) main);
         gtk_window_present ((GtkWindow *) eq);
     }
